Cheshire3 Object Model - Server
===============================

API
---

.. autoclass:: cheshire3.baseObjects.Server
   :members: get_config, get_default, get_object, get_path, get_setting

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.server.SimpleServer
